#!/usr/bin/env python

#****************************************************************************
#** $Id: sqlcustom2.py,v 1.1 2002/08/03 12:38:05 frispete Exp $
#**
#** Copyright (C) 1992-1998 Troll Tech AS.  All rights reserved.
#**
#** This file is part of an example program for PyQt.  This example
#** program may be used, distributed and modified without limitation.
#**
#*****************************************************************************/

import sys
from qt import *
from qtsql import *

from dbconnect import createConnection

TRUE  = 1
FALSE = 0

class CustomEdit(QLineEdit):
    def __init__(self, parent = None, name = None):
        QLineEdit.__init__(self, parent, name)
        QObject.connect(self, SIGNAL("textChanged(const QString &)"),
                        self.changed)

    def changed(self, line):
        #print "CE.changed()"
        self.setUpperLine(line)

    def setUpperLine(self, line):
        #print "CE.setUpperLine()"
        self.upperLineText = line.upper()
        self.setText(self.upperLineText)

    def upperLine(self):
        #print "CE.upperLine()"
        return self.upperLineText;


class FormDialog(QDialog):
    def __init__(self):
        QDialog.__init__(self)
        forenameLabel = QLabel("Forename:", self)
        forenameEdit = QLineEdit(self)
        surnameLabel = QLabel("Surname:", self)
        surnameEdit = CustomEdit(self)
        #surnameEdit = QLineEdit(self)
        salaryLabel = QLabel("Salary:", self)
        salaryEdit = QLineEdit(self)
        salaryEdit.setAlignment(Qt.AlignRight)
        statusLabel = QLabel("Status:", self)
        statusEdit = QSpinBox(self)
        nextButton = QPushButton("&Next", self)
        self.connect(nextButton, SIGNAL("clicked()"), self.next)
        saveButton = QPushButton("&Save", self)
        self.connect(saveButton, SIGNAL("clicked()"), self.save)

        grid = QGridLayout(self)
        grid.addWidget(forenameLabel, 0, 0)
        grid.addWidget(forenameEdit, 0, 1)
        grid.addWidget(surnameLabel, 1, 0)
        grid.addWidget(surnameEdit, 1, 1)
        grid.addWidget(salaryLabel, 2, 0)
        grid.addWidget(salaryEdit, 2, 1)
        grid.addWidget(statusLabel, 3, 0)
        grid.addWidget(statusEdit, 3, 1)
        grid.addWidget(nextButton, 4, 0)
        grid.addWidget(saveButton, 4, 1)
        grid.activate()

        staffCursor = QSqlCursor("staff")
        staffCursor.setTrimmed("forename", TRUE)
        staffCursor.setTrimmed("surname", TRUE)
        idIndex = staffCursor.index("id")
        staffCursor.select(idIndex)
        staffCursor.first()

        propMap = QSqlPropertyMap()
        propMap.insert("CustomEdit", "upperLine")

        sqlForm = QSqlForm()
        sqlForm.setRecord(staffCursor.primeUpdate())
        sqlForm.installPropertyMap(propMap)
        sqlForm.insert(forenameEdit, "forename")
        sqlForm.insert(surnameEdit, "surname")
        sqlForm.insert(salaryEdit, "salary")
        sqlForm.insert(statusEdit, "statusid")
        sqlForm.readFields()

        self.staffCursor = staffCursor
        self.idIndex = idIndex
        self.sqlForm = sqlForm

    def next(self):
        if self.staffCursor.isValid():
            if not self.staffCursor.next():
                self.staffCursor.first()
            self.sqlForm.setRecord(self.staffCursor.primeUpdate())
            self.sqlForm.readFields()

    def save(self):
        self.sqlForm.writeFields()
        self.staffCursor.update()
        self.staffCursor.select(self.idIndex)
        self.staffCursor.first()


if __name__=='__main__':
    app = QApplication( sys.argv )
    if createConnection():
        formDialog = FormDialog()
        formDialog.show()
        app.setMainWidget(formDialog)
        app.exec_loop()

